==> arg-services-1.1.0-sources.jar: de/uni_trier/recap/arg_services/cbr/v1beta/CasebaseServiceGrpc.java <==
package de.uni_trier.recap.arg_services.cbr.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.52.1)",
    comments = "Source: arg_services/cbr/v1beta/casebase.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class CasebaseServiceGrpc {

  private CasebaseServiceGrpc() {}

  public static final String SERVICE_NAME = "arg_services.cbr.v1beta.CasebaseService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> getCasebaseMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Casebase",
      requestType = de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest.class,
      responseType = de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> getCasebaseMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest, de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> getCasebaseMethod;
    if ((getCasebaseMethod = CasebaseServiceGrpc.getCasebaseMethod) == null) {
      synchronized (CasebaseServiceGrpc.class) {
        if ((getCasebaseMethod = CasebaseServiceGrpc.getCasebaseMethod) == null) {
          CasebaseServiceGrpc.getCasebaseMethod = getCasebaseMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest, de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Casebase"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse.getDefaultInstance()))
              .setSchemaDescriptor(new CasebaseServiceMethodDescriptorSupplier("Casebase"))
              .build();
        }
      }
    }
    return getCasebaseMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static CasebaseServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceStub>() {
        @java.lang.Override
        public CasebaseServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CasebaseServiceStub(channel, callOptions);
        }
      };
    return CasebaseServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static CasebaseServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceBlockingStub>() {
        @java.lang.Override
        public CasebaseServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CasebaseServiceBlockingStub(channel, callOptions);
        }
      };
    return CasebaseServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static CasebaseServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceFutureStub>() {
        @java.lang.Override
        public CasebaseServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CasebaseServiceFutureStub(channel, callOptions);
        }
      };
    return CasebaseServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class CasebaseServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void casebase(de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getCasebaseMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getCasebaseMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest,
                de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse>(
                  this, METHODID_CASEBASE)))
          .build();
    }
  }

  /**
   */
  public static final class CasebaseServiceStub extends io.grpc.stub.AbstractAsyncStub<CasebaseServiceStub> {
    private CasebaseServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CasebaseServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CasebaseServiceStub(channel, callOptions);
    }

    /**
     */
    public void casebase(de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getCasebaseMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class CasebaseServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<CasebaseServiceBlockingStub> {
    private CasebaseServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CasebaseServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CasebaseServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse casebase(de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getCasebaseMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class CasebaseServiceFutureStub extends io.grpc.stub.AbstractFutureStub<CasebaseServiceFutureStub> {
    private CasebaseServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CasebaseServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CasebaseServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> casebase(
        de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getCasebaseMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_CASEBASE = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final CasebaseServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(CasebaseServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_CASEBASE:
          serviceImpl.casebase((de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class CasebaseServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    CasebaseServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("CasebaseService");
    }
  }

  private static final class CasebaseServiceFileDescriptorSupplier
      extends CasebaseServiceBaseDescriptorSupplier {
    CasebaseServiceFileDescriptorSupplier() {}
  }

  private static final class CasebaseServiceMethodDescriptorSupplier
      extends CasebaseServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    CasebaseServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (CasebaseServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new CasebaseServiceFileDescriptorSupplier())
              .addMethod(getCasebaseMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> arg-services-1.5.9-sources.jar: de/uni_trier/recap/arg_services/cbr/v1beta/CasebaseServiceGrpc.java <==
package de.uni_trier.recap.arg_services.cbr.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.71.0)",
    comments = "Source: arg_services/cbr/v1beta/casebase.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class CasebaseServiceGrpc {

  private CasebaseServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "arg_services.cbr.v1beta.CasebaseService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> getCasebaseMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Casebase",
      requestType = de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest.class,
      responseType = de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> getCasebaseMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest, de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> getCasebaseMethod;
    if ((getCasebaseMethod = CasebaseServiceGrpc.getCasebaseMethod) == null) {
      synchronized (CasebaseServiceGrpc.class) {
        if ((getCasebaseMethod = CasebaseServiceGrpc.getCasebaseMethod) == null) {
          CasebaseServiceGrpc.getCasebaseMethod = getCasebaseMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest, de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Casebase"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse.getDefaultInstance()))
              .setSchemaDescriptor(new CasebaseServiceMethodDescriptorSupplier("Casebase"))
              .build();
        }
      }
    }
    return getCasebaseMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static CasebaseServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceStub>() {
        @java.lang.Override
        public CasebaseServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CasebaseServiceStub(channel, callOptions);
        }
      };
    return CasebaseServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports all types of calls on the service
   */
  public static CasebaseServiceBlockingV2Stub newBlockingV2Stub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceBlockingV2Stub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceBlockingV2Stub>() {
        @java.lang.Override
        public CasebaseServiceBlockingV2Stub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CasebaseServiceBlockingV2Stub(channel, callOptions);
        }
      };
    return CasebaseServiceBlockingV2Stub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static CasebaseServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceBlockingStub>() {
        @java.lang.Override
        public CasebaseServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CasebaseServiceBlockingStub(channel, callOptions);
        }
      };
    return CasebaseServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static CasebaseServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CasebaseServiceFutureStub>() {
        @java.lang.Override
        public CasebaseServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CasebaseServiceFutureStub(channel, callOptions);
        }
      };
    return CasebaseServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void casebase(de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getCasebaseMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service CasebaseService.
   */
  public static abstract class CasebaseServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return CasebaseServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service CasebaseService.
   */
  public static final class CasebaseServiceStub
      extends io.grpc.stub.AbstractAsyncStub<CasebaseServiceStub> {
    private CasebaseServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CasebaseServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CasebaseServiceStub(channel, callOptions);
    }

    /**
     */
    public void casebase(de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getCasebaseMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service CasebaseService.
   */
  public static final class CasebaseServiceBlockingV2Stub
      extends io.grpc.stub.AbstractBlockingStub<CasebaseServiceBlockingV2Stub> {
    private CasebaseServiceBlockingV2Stub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CasebaseServiceBlockingV2Stub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CasebaseServiceBlockingV2Stub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse casebase(de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getCasebaseMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do limited synchronous rpc calls to service CasebaseService.
   */
  public static final class CasebaseServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<CasebaseServiceBlockingStub> {
    private CasebaseServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CasebaseServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CasebaseServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse casebase(de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getCasebaseMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service CasebaseService.
   */
  public static final class CasebaseServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<CasebaseServiceFutureStub> {
    private CasebaseServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CasebaseServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CasebaseServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse> casebase(
        de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getCasebaseMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_CASEBASE = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_CASEBASE:
          serviceImpl.casebase((de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getCasebaseMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseRequest,
              de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseResponse>(
                service, METHODID_CASEBASE)))
        .build();
  }

  private static abstract class CasebaseServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    CasebaseServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.cbr.v1beta.CasebaseProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("CasebaseService");
    }
  }

  private static final class CasebaseServiceFileDescriptorSupplier
      extends CasebaseServiceBaseDescriptorSupplier {
    CasebaseServiceFileDescriptorSupplier() {}
  }

  private static final class CasebaseServiceMethodDescriptorSupplier
      extends CasebaseServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    CasebaseServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (CasebaseServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new CasebaseServiceFileDescriptorSupplier())
              .addMethod(getCasebaseMethod())
              .build();
        }
      }
    }
    return result;
  }
}
